"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils_1 = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
class Add extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.lbMapsAdd = async (args, flags) => {
            var _a, _b;
            try {
                const { lb, index } = await (0, utils_1.findLoadBalancer)(this.session.selectedOrganization.id, args.name, args.certificateName);
                const url = uris.loadBalancer(this.session.selectedOrganization.id, lb.vpc.id, lb.id);
                const body = [{
                        op: 'add',
                        path: '/sslEndpoints/' + index + '/mappings/0',
                        value: {
                            inputUri: args.inputUri,
                            appName: args.appName,
                            appUri: args.appUri,
                            upstreamProtocol: flags.upstreamProtocol || 'http',
                        },
                    }];
                const endpoint = (await this.req.patch(url, body)).data;
                this.log('Mappings for Load balancer', endpoint.name, 'updated successfully');
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(Add);
        await this.lbMapsAdd(args, flags);
    }
}
exports.default = Add;
Add.description = 'Add a proxy mapping rule at index 0' +
    'If no certificateName is given, the mappings is added to the default SSL endpoint';
Add.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    upstreamProtocol: core_1.Flags.string({ description: 'Look for upstream applications in HTTP port 8091 or HTTPS port 8092. Supported Values: http, https' }),
};
Add.args = [{ name: 'name', required: true },
    { name: 'inputUri', required: true },
    { name: 'appName', required: true },
    { name: 'appUri', required: true },
    { name: 'certificateName' }];
