"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils_1 = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const _ = require("lodash");
class SetDefault extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.lbSslEndpointSetDefault = async (name, certificateName, http) => {
            var _a, _b;
            const orgId = this.session.selectedOrganization.id;
            try {
                const lb = await (0, utils_1.getLoadBalancerByName)(orgId, name);
                const index = _.findIndex(lb.sslEndpoints, { publicKeyCN: certificateName });
                if (index === -1) {
                    this.error('An SSL endpoint with Common Name ' + certificateName + ' was not found');
                }
                const body = [{
                        op: 'replace',
                        path: '/defaultSslEndpoint',
                        value: index.toString(),
                    }];
                if (http) {
                    body.push({
                        op: 'replace',
                        path: '/httpMode',
                        value: http,
                    });
                }
                await this.req.patch(uris.loadBalancer(orgId, lb.vpc.id, lb.id), body);
                this.log('Load balancer', lb.name, 'updated successfully');
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(SetDefault);
        await this.lbSslEndpointSetDefault(args.name, args.certificateName, flags.http);
    }
}
exports.default = SetDefault;
SetDefault.description = 'Set the default certificate that the Load balancer will serve';
SetDefault.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    http: core_1.Flags.string({ options: ['on', 'off', 'redirect'] }),
};
SetDefault.args = [{ name: 'name', required: true },
    { name: 'certificateName', required: true }];
