"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const anypoint_cli_command_1 = require("anypoint-cli-command");
const JSZip = require("jszip");
const moment = require("moment");
const uris_1 = require("../../../helpers/uris");
const util_1 = require("util");
const Path = require('upath');
const fse = require('fs-extra');
class DownloadLogs extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args } = await this.parse(DownloadLogs);
        const orgId = this.session.selectedOrganization.id;
        const envId = this.session.selectedEnvironment.id;
        await this.appDownloadLogs(orgId, envId, args);
    }
    async appDownloadLogs(orgId, envId, args) {
        var _a, _b;
        try {
            const { data: loglines } = await this.req.get((0, uris_1.cloudHub2LogsFile)(orgId, envId, args.appId, args.specId), { headers: { Accept: '*/*' } });
            this.log('Downloading logs...');
            await this.zipLogs(loglines, args);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
    zipLogs(logLines, args) {
        const zip = new JSZip();
        if (logLines) {
            zip.file(args.appId + '.txt', logLines);
        }
        const date = moment.utc().format('YYYY_MM_DD');
        const zipPath = Path.join(args.directory, (0, util_1.format)('%s-%s.zip', args.appId, date));
        this.log('Saving to', zipPath);
        return zip
            .generateAsync({
            type: 'nodebuffer',
            // platform: process.platform,
        })
            .then(function (data) {
            fse.writeFileSync(zipPath, data);
        });
    }
}
exports.default = DownloadLogs;
DownloadLogs.description = 'Download application logs to specified directory';
DownloadLogs.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
};
DownloadLogs.args = [{ name: 'appId', required: true }, { name: 'specId', required: true }, { name: 'directory', required: true }];
